Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/mc3479_simpletest.py
    :caption: examples/mc3479_simpletest.py
    :linenos:

Acceleration Data Range
------------------------

Example showing how to change the acceleration data range

.. literalinclude:: ../examples/mc3479_acceleration_range.py
    :caption: examples/mc3479_acceleration_range.py
    :linenos:
